@@ -46,7 +46,7 @@ class Video(Scene):
                  mindim=512,
                  dt=1,
                  fetch=True,
-                 attributes=None
+                 attributes=None,
     ):
         assert (mp4file is not None or mp4url is not None), "Invalid input - Must provide either mp4file or mp4url"
         assert (jsonurl is not None or jsonfile is not None), "Invalid input - Must provide either jsonurl or jsonfile"
@@ -55,13 +55,11 @@ class Video(Scene):
 
         # AWS credentials (if needed) must be set by pycollector.user
         if ((jsonurl is not None and (jsonfile is None or not os.path.exists(jsonfile))) or
-            (mp4url is not None and (mp4file is None or not os.path.exists(mp4file)))):            
+            (mp4url is not None and (mp4file is None or not os.path.exists(mp4file)))):
              assert 'VIPY_AWS_ACCESS_KEY_ID' in os.environ and 'VIPY_AWS_SECRET_ACCESS_KEY' in os.environ, "AWS access keys not found - Log in using pycollector.user"
         
         # Vipy video constructor
-        mp4url = mp4url.replace('+',' ') if mp4url is not None else mp4url  # for cut and paste from AWS console
-        jsonurl = jsonurl.replace('+',' ') if jsonurl is not None else jsonurl  # for cut and paste from AWS console        
-        super(Video, self).__init__(url=mp4url, filename=mp4file, attributes=attributes)
+        super().__init__(url=mp4url, filename=mp4file, attributes=attributes)
 
         # Video attributes
         #self._quicklook_url = "https://%s.s3.amazonaws.com/Quicklooks/%%s_quicklook_%%s_%%d.jpg" % (backend().s3_bucket())   # FIXME: pycollector.admin.video
@@ -81,7 +79,7 @@ class Video(Scene):
                                                                                   if self.timestamp() is not None
                                                                                   else str(None),
                                                                                   self.activity_categories(),
-                                                                                  str(super(Video, self).__repr__())))
+                                                                                  str(super().__repr__())))
             
     def _load_json(self):
         """Lazy JSON download, parse, and import"""
@@ -237,12 +235,14 @@ class Video(Scene):
             d_shortname_to_category = {s:c for (s,c) in zip(d['metadata']['shortname'].split(','), d['metadata']['category'].split(','))}            
             if '#' in d['metadata']['category']:
                 d_shortname_to_category = {s:c.split('#')[0] for (s,c) in d_shortname_to_category.items()}
-                variantlist = [c.split('#')[1] if '#' in c else None for c in d['metadata']['category'].split(',')]
-                assert len(set(variantlist)) == 1, "Variants must be identical across activities"
-                v = variantlist[0]
-                assert v is None or '#' not in v, "Variants must follow URI fragment syntax"
-                variant = {k.split('=')[0]:k.split('=')[1] for k in v.split('&') if '=' in k} if (v is not None and '&' in v) else {}
-                self.attributes['variant'] = variant
+                variantlist = list(set([c.split('#')[1] if '#' in c else None for c in d['metadata']['category'].split(',')]))
+                if len(variantlist) != 1 or (variantlist[0] is not None and '=' not in variantlist[0]):
+                    print('[pycollector.video]: WARNING - Ignoring invalid variant "%s"' % str(variantlist))
+                    variant = {}
+                else:
+                    v = variantlist[0]
+                    variant = {k.split('=')[0]:k.split('=')[1] for k in v.split('&') if '=' in k} if (v is not None and '&' in v) else {}
+                    self.attributes['variant'] = variant
             
             # Import activities
             for a in d["activity"]:
@@ -259,7 +259,6 @@ class Video(Scene):
                         shortlabel = "Buying (Cashier)"
                     else:
                         shortlabel = a["label"]
-                    shortlabel = shortlabel.lower()
 
                     #category = backend().collection()[d["metadata"]["collection_id"]].shortname_to_activity(a["label"])
                     category = d_shortname_to_category[a['label']]
@@ -311,7 +310,7 @@ class Video(Scene):
             self._is_json_loaded = False
 
         # Resample tracks
-        if self._dt > 1:
+        if self._dt > 1 and self._is_json_loaded:
             self.trackmap(lambda t: t.resample(self._dt))
         
         return self
@@ -334,7 +333,7 @@ class Video(Scene):
         return self.fetchvideo()
 
     def fetchvideo(self, ignoreErrors=False):
-        super(Video, self).fetch()
+        super().fetch()
         return self
 
     def fetchjson(self):
